%global genericname gdata

Name:          %{genericname}-java
Version:       1.45.0
Release:       %mkrel 3
Summary:       Google Data Java Client Library
Group:         Development/Java
License:       ASL 2.0
Url:           http://code.google.com/p/gdata-java-client/
Source0:       http://gdata-java-client.googlecode.com/files/gdata-src.java-%{version}.zip
Source1:       %{genericname}-core-%{version}-pom.xml

BuildRequires: java-devel
BuildRequires: jpackage-utils

BuildRequires: ant
BuildRequires: guava
BuildRequires: javamail
BuildRequires: jsr-305
BuildRequires: servlet25

Requires:      jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:      java
BuildArch:     noarch


%description
The client library provides tools and an abstraction layer, letting you
easily construct queries and use response data without having to create
HTTP requests or process HTTP responses by hand. Each client library
provides classes that correspond to the elements and data types used by
the Google Data APIs. Each client library also provides extensions for
specific Google services that have Data APIs.

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      %{name} = %{version}-%{release}

%description javadoc
%{genericname} development documentation.

%prep
%setup -q -n %{genericname}

pushd java

rm -rf lib/* gdata/java/deps/* classes doc

properties=build-src/build.properties
for jars in \
  "servlet servlet" \
  "mail javamail/mail" \
  "activation activation" \
  "guava jsr-305"
do
  f=`echo $jars | gawk '{print $1;}'`
  g=`echo $jars | gawk '{print $2;}'`
  %{__sed} -i -e "/^${f}/s|=.*$|=`build-classpath ${g}`|" $properties
done

  for i in $(ls manifest/*.manifest); do
    %{__sed} -i '/class-path/I d' $i
    echo "Export-Package: $(grep '^Name' $i | sed -e 's|^Name: *||' -e 's|/|.|g' -e 's|.$||');version=\"%{version}\"" >> $i
  done

popd

%build

pushd java
ant \
  -lib lib/%{genericname}-core-1.0.jar:lib/%{genericname}-client-1.0.jar \
  -buildfile build-src.xml \
  clean build

javadoc -d doc \
  -classpath $(build-classpath guava javamail/mail jsr-305):%java_home/lib/tools.jar \
  -encoding iso-8859-1 \
  -public \
  `find src -name \*.java`
popd

%install
[ %{buildroot} != / ] && rm -rf %{buildroot}

pushd java
  pushd lib
    mkdir -p %{buildroot}%{_javadir}/%{genericname}
    install -m 644 *.jar %{buildroot}%{_javadir}/%{genericname}
    for i in `ls *.jar`; do
      x=`echo $i | tr -d [:digit:]`
      ln -s $i %{buildroot}%{_javadir}/%{genericname}/${x%%-\.\.jar}.jar
    done
  popd

  mkdir -p %{buildroot}%{_javadocdir}/%{genericname}
  cp -rp doc/* %{buildroot}%{_javadocdir}/%{genericname}
popd

# pom dir
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}

# pom
# Only %{genericname}-core included for now, feel free to add more artifacts to pom file if you need
install -pm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{genericname}-%{genericname}-core.pom

# depmap
%add_maven_depmap JPP.%{genericname}-%{genericname}-core.pom %{genericname}/%{genericname}-core.jar


%files
%dir %{_javadir}/%{genericname}
%{_javadir}/%{genericname}/%{genericname}-*.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc COPYING

%files javadoc
%{_javadocdir}/%{genericname}

%changelog

* Fri Jan 11 2013 umeabot <umeabot> 1.45.0-3.mga3
+ Revision: 351124
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 17 2012 gil <gil> 1.45.0-2.mga2
+ Revision: 197373
- build fix
  removed geronimo jaf apis (used jvm apis)

* Mon Dec 26 2011 gil <gil> 1.45.0-1.mga2
+ Revision: 187907
- build fix release
- New version

* Wed Jul 20 2011 dmorgan <dmorgan> 1.41.2-1.mga2
+ Revision: 127244
- Sync spec file with fedora

  + gil <gil>
    - imported package gdata-java

